@@ -1,13 +1,12 @@
-static char *rcsid = "$Header: /silver/homes/zeus/Blind-2.44/RCS/new-game.c,v 2.44 1995/12/31 19:45:18 zeus Exp zeus $";
+static char *rcsid = "$Header: /plaid/homes/zeus/Blind-2.45/RCS/new-game.c,v 2.45 1996/12/31 23:40:54 zeus Exp zeus $";
 
 /*
  * $Log: new-game.c,v $
+ * Revision 2.45  1996/12/31  23:40:54  zeus
+ * *** empty log message ***
+ *
  * Revision 2.44  1995/12/31  19:45:18  zeus
- * *** empty log message ***
- *
  * Revision 2.43  1995/03/20  01:43:09  zeus
- * *** empty log message ***
- *
  * Revision 2.42  1994/05/17  13:43:15  bampton
  * Revision 2.41  1994/04/08  03:11:28  bampton
  * Revision 2.40  1994/03/09  20:22:55  bampton
@@ -35,6 +34,10 @@ extern planet *planets;
 extern player *players;
 extern double galaxysize;
 extern int nplanets;
+#ifdef GAMENAME
+extern char gamename[];
+extern char buf[];
+#endif
 
 /* Algorithm: for creating new galaxies:
   1) Do players, and make them at least MINSEP apart.
@@ -204,7 +207,7 @@ balance_galaxy (void)
   player *P;
   planet *p, *ph;
 
-  vals = alloc ((unsigned)sizeof (double) * listlen (players));
+  vals = alloc ((unsigned)sizeof (double) * (listlen (players)+1));
 
   do
   {
